@@ -42,24 +42,20 @@ class TestSnapReviewLint(sr_tests.TestSnapReview):
         return ports
 
     def _create_top_plugs(self):
-        plugs = {'iface-caps': {'interface': 'old-security',
-                                'caps': ['network']},
-                 'iface-override': {'interface': 'old-security',
-                                    'security-override': {"read_path": "/foo/",
-                                                          "seccomp": "abc"}},
-                 'iface-policy': {'interface': 'old-security',
-                                  'security-policy': {"apparmor": "meta/aa",
-                                                      "seccomp": "meta/sc"}},
-                 'iface-template': {'interface': 'old-security',
-                                    'security-template': "unconfined"}
+        plugs = {'iface-bool-file': {'interface': 'bool-file',
+                                     'path': '/path/to/something'},
+                 'iface-network': {'interface': 'network'},
+                 'iface-network-bind': {'interface': 'network-bind'},
+                 # intentionally omitted
+                 # 'iface-network-control': {'interface': 'network-control'},
                  }
         return plugs
 
     def _create_apps_plugs(self):
-        plugs = {'app1': {'plugs': ['iface-caps']},
-                 'app2': {'plugs': ['iface-caps', 'iface-template']},
-                 'app3': {'plugs': ['iface-template', 'iface-override']},
-                 'app4': {'plugs': ['iface-policy']},
+        plugs = {'app1': {'plugs': ['iface-network']},
+                 'app2': {'plugs': ['iface-network-bind']},
+                 'app3': {'plugs': ['network-control']},
+                 'app4': {'plugs': ['iface-bool-file']},
                  }
         return plugs
 
@@ -489,6 +485,24 @@ class TestSnapReviewLint(sr_tests.TestSnapReview):
         expected_counts = {'info': 1, 'warn': 0, 'error': 0}
         self.check_results(r, expected_counts)
 
+    def test_check_architectures_single_s390x(self):
+        '''Test check_architectures() (single arch, s390x)'''
+        self.set_test_snap_yaml("architectures", ["s390x"])
+        c = SnapReviewLint(self.test_name)
+        c.check_architectures()
+        r = c.click_report
+        expected_counts = {'info': 1, 'warn': 0, 'error': 0}
+        self.check_results(r, expected_counts)
+
+    def test_check_architectures_single_ppc64el(self):
+        '''Test check_architectures() (single arch, ppc64el)'''
+        self.set_test_snap_yaml("architectures", ["ppc64el"])
+        c = SnapReviewLint(self.test_name)
+        c.check_architectures()
+        r = c.click_report
+        expected_counts = {'info': 1, 'warn': 0, 'error': 0}
+        self.check_results(r, expected_counts)
+
     def test_check_architectures_single_nonexistent(self):
         '''Test check_architectures() (single nonexistent arch)'''
         self.set_test_snap_yaml("architectures", ["nonexistent"])
@@ -1883,7 +1897,7 @@ class TestSnapReviewLint(sr_tests.TestSnapReview):
         c = SnapReviewLint(self.test_name)
         c.check_plugs()
         r = c.click_report
-        expected_counts = {'info': 13, 'warn': 0, 'error': 0}
+        expected_counts = {'info': 8, 'warn': 0, 'error': 0}
         self.check_results(r, expected_counts)
 
     def test_check_plugs_bad_interface(self):
@@ -1910,7 +1924,7 @@ class TestSnapReviewLint(sr_tests.TestSnapReview):
 
     def test_check_plugs_unspecified_interface(self):
         '''Test check_plugs() - unspecified interface'''
-        plugs = {'old-security': {'caps': ['network']}}
+        plugs = {'bool-file': {'path': '/path/to/some/where'}}
         self.set_test_snap_yaml("plugs", plugs)
         c = SnapReviewLint(self.test_name)
         c.check_plugs()
@@ -1929,6 +1943,17 @@ class TestSnapReviewLint(sr_tests.TestSnapReview):
         expected_counts = {'info': None, 'warn': 0, 'error': 1}
         self.check_results(r, expected_counts)
 
+    def test_check_plugs_unknown_interface_old_security(self):
+        '''Test check_plugs() - interface (old-security)'''
+        plugs = {'iface-caps': {'interface': 'old-security',
+                                'caps': ['network']}}
+        self.set_test_snap_yaml("plugs", plugs)
+        c = SnapReviewLint(self.test_name)
+        c.check_plugs()
+        r = c.click_report
+        expected_counts = {'info': None, 'warn': 0, 'error': 1}
+        self.check_results(r, expected_counts)
+
     def test_check_plugs_unspecified_unknown_interface(self):
         '''Test check_plugs() - unspecified interface (unknown)'''
         plugs = {'nonexistent': {'caps': ['network']}}
@@ -1941,7 +1966,7 @@ class TestSnapReviewLint(sr_tests.TestSnapReview):
 
     def test_check_plugs_missing_attrib(self):
         '''Test check_plugs() - missing attrib'''
-        plugs = {'old-security': {}}
+        plugs = {'bool-file': {}}
         self.set_test_snap_yaml("plugs", plugs)
         c = SnapReviewLint(self.test_name)
         c.check_plugs()
@@ -1951,7 +1976,7 @@ class TestSnapReviewLint(sr_tests.TestSnapReview):
 
     def test_check_plugs_missing_attrib_explicit_interface(self):
         '''Test check_plugs() - missing attrib'''
-        plugs = {'iface-caps': {'interface': 'old-security'}}
+        plugs = {'test': {'interface': 'bool-file'}}
         self.set_test_snap_yaml("plugs", plugs)
         c = SnapReviewLint(self.test_name)
         c.check_plugs()
@@ -1961,8 +1986,8 @@ class TestSnapReviewLint(sr_tests.TestSnapReview):
 
     def test_check_plugs_unknown_attrib(self):
         '''Test check_plugs() - unknown attrib'''
-        plugs = {'iface-caps': {'interface': 'old-security',
-                                'nonexistent': 'abc'}}
+        plugs = {'test': {'interface': 'bool-file',
+                          'nonexistent': 'abc'}}
         self.set_test_snap_yaml("plugs", plugs)
         c = SnapReviewLint(self.test_name)
         c.check_plugs()
@@ -1971,42 +1996,9 @@ class TestSnapReviewLint(sr_tests.TestSnapReview):
         self.check_results(r, expected_counts)
 
     def test_check_plugs_bad_attrib_caps(self):
-        '''Test check_plugs() - bad attrib - caps'''
-        plugs = {'iface-caps': {'interface': 'old-security',
-                                'caps': 'bad'}}
-        self.set_test_snap_yaml("plugs", plugs)
-        c = SnapReviewLint(self.test_name)
-        c.check_plugs()
-        r = c.click_report
-        expected_counts = {'info': None, 'warn': 0, 'error': 1}
-        self.check_results(r, expected_counts)
-
-    def test_check_plugs_bad_attrib_security_override(self):
-        '''Test check_plugs() - bad attrib - security-override'''
-        plugs = {'iface-caps': {'interface': 'old-security',
-                                'security-override': 'bad'}}
-        self.set_test_snap_yaml("plugs", plugs)
-        c = SnapReviewLint(self.test_name)
-        c.check_plugs()
-        r = c.click_report
-        expected_counts = {'info': None, 'warn': 0, 'error': 1}
-        self.check_results(r, expected_counts)
-
-    def test_check_plugs_bad_attrib_security_policy(self):
-        '''Test check_plugs() - bad attrib - security-policy'''
-        plugs = {'iface-caps': {'interface': 'old-security',
-                                'security-policy': 'bad'}}
-        self.set_test_snap_yaml("plugs", plugs)
-        c = SnapReviewLint(self.test_name)
-        c.check_plugs()
-        r = c.click_report
-        expected_counts = {'info': None, 'warn': 0, 'error': 1}
-        self.check_results(r, expected_counts)
-
-    def test_check_plugs_bad_attrib_security_template(self):
-        '''Test check_plugs() - bad attrib - security-template'''
-        plugs = {'iface-caps': {'interface': 'old-security',
-                                'security-template': []}}
+        '''Test check_plugs() - bad attrib - bool-file'''
+        plugs = {'test': {'interface': 'bool-file',
+                          'path': ['invalid']}}
         self.set_test_snap_yaml("plugs", plugs)
         c = SnapReviewLint(self.test_name)
         c.check_plugs()
@@ -2023,7 +2015,7 @@ class TestSnapReviewLint(sr_tests.TestSnapReview):
         c = SnapReviewLint(self.test_name)
         c.check_apps_plugs()
         r = c.click_report
-        expected_counts = {'info': 10, 'warn': 0, 'error': 0}
+        expected_counts = {'info': 8, 'warn': 0, 'error': 0}
         self.check_results(r, expected_counts)
 
     def test_check_apps_no_plugs(self):
